@@ -24,16 +24,9 @@ qr2scad < example.png > example.scad
 
 <http://www.thingiverse.com/thing:4448>
 
-Bugs:
-
-Please email bug reports to victor dot engmark at gmail dot com.
+Bugs: <https://github.com/l0b0/qr2scad/issues>
 """
 
-__author__ = 'Victor Engmark'
-__email__ = 'victor.engmark@gmail.com'
-__copyright__ = 'Copyright (C) 2010 Victor Engmark'
-__license__ = 'GPLv3'
-
 from PIL import Image, ImageOps
 from signal import signal, SIGPIPE, SIG_DFL
 import sys
@@ -86,8 +79,11 @@ def qr2scad(stream):
 
     qr_side = width
 
+    # QR code superpixel size
+    qr_pixel_size = (list(img.getdata()).index(0) / PDP_SIDE)
+
     # Get the resize factor from the PDP size
-    new_size = qr_side / (list(img.getdata()).index(0) / (PDP_SIDE - 1))
+    new_size = qr_side / qr_pixel_size
 
     # Set a more reasonable size
     img = img.resize((new_size, new_size))
@@ -108,14 +104,13 @@ def qr2scad(stream):
                 result += ' cube([%(block_side)s, %(block_side)s, 1]);\n' % {
                     'block_side': BLOCK_SIDE
                 }
-    result += '}\n'
+    result += '}'
 
     return result
 
 
 def main(argv=None):
-    result = qr2scad(sys.stdin)
-    print result
+    print qr2scad(sys.stdin)
 
 if __name__ == '__main__':
     sys.exit(main())
